==> mirrorfly_uikit_plugin-1.0.0.tar.gz: lib/app/modules/chat/views/chat_list_view.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:get/get.dart';
import 'package:mirrorfly_plugin/logmessage.dart';
import 'package:mirrorfly_uikit_plugin/app/common/extensions.dart';
import 'package:mirrorfly_uikit_plugin/app/modules/chat/controllers/chat_controller.dart';
import 'package:mirrorfly_uikit_plugin/mirrorfly_uikit_plugin.dart';
import 'package:scrollable_positioned_list/scrollable_positioned_list.dart';
import 'package:swipe_to/swipe_to.dart';

import '../../../common/constants.dart';
import '../../../model/chat_message_model.dart';
import '../chat_widgets.dart';

class ChatListView extends StatefulWidget {
  final ChatController chatController;
  final List<ChatMessageModel> chatList;

  const ChatListView(
      {super.key, required this.chatController, required this.chatList});

  @override
  State<ChatListView> createState() => _ChatListViewState();
}

class _ChatListViewState extends State<ChatListView> {
  @override
  Widget build(BuildContext context) {
    // super.build(context);
    debugPrint("ChatListView build view");
    return Align(
      alignment: Alignment.bottomCenter,
      child: NotificationListener<ScrollNotification>(
        onNotification: (notification) {
          if (notification is ScrollEndNotification) {
            widget.chatController.loadNextChatHistory();
          }
          return false;
        },
        child: Obx(() {
          return ScrollablePositionedList.separated(
            separatorBuilder: (context, index) {
              var string =
                  groupedDateMessage(index, widget.chatList); //Date Labels
              return string != null
                  ? NotificationMessageView(chatMessage: string)
                  : const Offstage();
            },
            itemScrollController: widget.chatController.newScrollController,
            itemPositionsListener:
                widget.chatController.newitemPositionsListener,
            itemCount: widget.chatList.length,
            shrinkWrap: true,
            reverse: true,
            itemBuilder: (context, pos) {
              final index = pos;
              LogMessage.d("ScrollablePositionedList",
                  "build $index ${widget.chatList[index].messageId}");
              return Column(
                mainAxisSize: MainAxisSize.min,
                children: [
                  Obx(() {
                    LogMessage.d(
                        "ScrollablePositionedList inside AutomaticKeepAlive",
                        "build $index");
                    return widget.chatController.showLoadingPrevious.value &&
                            index == widget.chatList.length - 1
                        ? const Center(child: CircularProgressIndicator())
                        : const Offstage();
                  }),
                  (widget.chatList[index].messageType.toUpperCase() !=
                          Constants.mNotification)
                      ? SwipeTo(
                          onRightSwipe: (DragUpdateDetails dragUpdateDetails) {
                            if (!widget
                                    .chatList[index].isMessageRecalled.value &&
                                !widget.chatList[index].isMessageDeleted &&
                                widget.chatList[index].messageStatus.value
                                        .checkNull()
                                        .toString() !=
                                    "N") {
                              widget.chatController.handleReplyChatMessage(
                                  widget.chatList[index]);
                            }
                          },
                          animationDuration: const Duration(milliseconds: 300),
                          offsetDx: 0.2,
                          child: GestureDetector(
                            onLongPress: () {
                              debugPrint("LongPressed");
                              FocusManager.instance.primaryFocus?.unfocus();
                              if (!widget.chatController.isSelected.value) {
                                widget.chatController.isSelected(true);
                                widget.chatController
                                    .addChatSelection(widget.chatList[index]);
                              }
                            },
                            onTap: () {
                              debugPrint("On Tap");
                              FocusManager.instance.primaryFocus?.unfocus();
                              if (widget.chatController.isSelected.value) {
                                widget.chatController.isSelected.value
                                    ? widget.chatController.selectedChatList
                                            .contains(widget.chatList[index])
                                        ? widget.chatController
                                            .clearChatSelection(
                                                widget.chatList[index])
                                        : widget.chatController
                                            .addChatSelection(
                                                widget.chatList[index])
                                    : null;
                                widget.chatController.getMessageActions();
                              } else {
                                var replyChat = widget
                                    .chatList[index].replyParentChatMessage;
                                if (replyChat != null) {
                                  debugPrint("reply tap ");
                                  var chat = widget.chatList.indexWhere(
                                      (element) =>
                                          element.messageId ==
                                          replyChat.messageId);
                                  if (!chat.isNegative) {
                                    widget.chatController.navigateToMessage(
                                        widget.chatList[chat],
                                        index: chat);
                                  }
                                }
                              }
                            },
                            onDoubleTap: () {
                              widget.chatController.translateMessage(index);
                            },
                            child: Obx(() {
                              LogMessage.d("Container",
                                  "build ${widget.chatList[index].messageId}");
                              return Container(
                                key: ValueKey(widget.chatList[index].messageId),
                                color: widget.chatList[index].isSelected.value
                                    ? MirrorflyUikit.getTheme?.primaryColor
                                        .withAlpha(60)
                                    : Colors.transparent,
                                margin: const EdgeInsets.only(
                                    left: 14, right: 14, top: 5, bottom: 10),
                                child: Align(
                                  alignment:
                                      (widget.chatList[index].isMessageSentByMe
                                          ? Alignment.bottomRight
                                          : Alignment.bottomLeft),
                                  child: Row(
                                    crossAxisAlignment:
                                        CrossAxisAlignment.center,
                                    mainAxisSize: MainAxisSize.min,
                                    children: [
                                      Visibility(
                                        visible: widget.chatController
                                            .forwardMessageVisibility(
                                                widget.chatList[index]),
                                        child: IconButton(
                                            onPressed: () {
                                              widget.chatController
                                                  .forwardSingleMessage(widget
                                                      .chatList[index]
                                                      .messageId);
                                            },
                                            icon:
                                                SvgPicture.asset(forwardMedia)),
                                      ),
                                      ChatContainer(
                                        chatMessage: widget.chatList[index],
                                        child: Column(
                                          crossAxisAlignment:
                                              CrossAxisAlignment.start,
                                          children: [
                                            if (widget.chatController.profile
                                                .isGroupProfile
                                                .checkNull()) ...[
                                              SenderHeader(
                                                  isGroupProfile: widget
                                                      .chatController
                                                      .profile
                                                      .isGroupProfile,
                                                  chatList: widget.chatList,
                                                  index: index),
                                            ],
                                            widget.chatList[index]
                                                    .isThisAReplyMessage
                                                ? widget.chatList[index]
                                                            .replyParentChatMessage ==
                                                        null
                                                    ? messageNotAvailableWidget(
                                                        widget.chatList[index])
                                                    : ReplyMessageHeader(
                                                        chatMessage: widget
                                                            .chatList[index])
                                                : const SizedBox.shrink(),
                                            MessageContent(
                                                chatList: widget.chatList,
                                                index: index,
                                                onPlayAudio: () {
                                                  if (widget
                                                          .chatController
                                                          .isAudioRecording
                                                          .value ==
                                                      Constants
                                                          .audioRecording) {
                                                    widget.chatController
                                                        .stopRecording();
                                                  }
                                                  widget.chatController
                                                      .playAudio(widget
                                                          .chatList[index]);
                                                },
                                                onSeekbarChange:
                                                    (double value) {
                                                  widget.chatController
                                                      .onSeekbarChange(
                                                          value,
                                                          widget
                                                              .chatList[index]);
                                                },
                                                isSelected: widget
                                                    .chatController
                                                    .isSelected
                                                    .value)
                                          ],
                                        ),
                                      ),
                                      if (!widget.chatList[index]
                                              .isMessageSentByMe &&
                                          widget.chatController
                                              .forwardMessageVisibility(
                                                  widget.chatList[index])) ...[
                                        IconButton(
                                            onPressed: () {
                                              widget.chatController
                                                  .forwardSingleMessage(widget
                                                      .chatList[index]
                                                      .messageId);
                                            },
                                            icon:
                                                SvgPicture.asset(forwardMedia))
                                      ],
                                    ],
                                  ),
                                ),
                              );
                            }),
                          ),
                        )
                      : NotificationMessageView(
                          chatMessage:
                              widget.chatList[index].messageTextContent),
                  Obx(() {
                    return widget.chatController.showLoadingNext.value &&
                            index == 0
                        ? const Center(
                            child: CircularProgressIndicator(),
                          )
                        : const Offstage();
                  }),
                ],
              );
            },
          );
        }),
      ),
    );
  }
  //
  // @override
  // bool get wantKeepAlive => true;
}

==> mirrorfly_uikit_plugin-1.0.1.tar.gz: lib/app/modules/chat/views/chat_list_view.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:get/get.dart';
import 'package:mirrorfly_plugin/logmessage.dart';
import 'package:mirrorfly_uikit_plugin/app/common/extensions.dart';
import 'package:mirrorfly_uikit_plugin/app/modules/chat/controllers/chat_controller.dart';
import 'package:mirrorfly_uikit_plugin/mirrorfly_uikit_plugin.dart';
import 'package:scrollable_positioned_list/scrollable_positioned_list.dart';
import 'package:swipe_to/swipe_to.dart';

import '../../../common/constants.dart';
import '../../../model/chat_message_model.dart';
import '../chat_widgets.dart';

class ChatListView extends StatefulWidget {
  final ChatController chatController;
  final List<ChatMessageModel> chatList;

  const ChatListView(
      {super.key, required this.chatController, required this.chatList});

  @override
  State<ChatListView> createState() => _ChatListViewState();
}

class _ChatListViewState extends State<ChatListView> {
  @override
  Widget build(BuildContext context) {
    // super.build(context);
    debugPrint("ChatListView build view");
    return Align(
      alignment: Alignment.bottomCenter,
      child: NotificationListener<ScrollNotification>(
        onNotification: (notification) {
          if (notification is ScrollEndNotification) {
            widget.chatController.loadNextChatHistory();
          }
          return false;
        },
        child: Obx(() {
          return ScrollablePositionedList.separated(
            separatorBuilder: (context, index) {
              var string =
                  groupedDateMessage(index, widget.chatList); //Date Labels
              return string != null
                  ? NotificationMessageView(chatMessage: string)
                  : const Offstage();
            },
            itemScrollController: widget.chatController.newScrollController,
            itemPositionsListener:
                widget.chatController.newitemPositionsListener,
            itemCount: widget.chatList.length,
            shrinkWrap: true,
            reverse: true,
            itemBuilder: (context, pos) {
              final index = pos;
              LogMessage.d("ScrollablePositionedList",
                  "build $index ${widget.chatList[index].messageId}");
              return Column(
                mainAxisSize: MainAxisSize.min,
                children: [
                  Obx(() {
                    LogMessage.d(
                        "ScrollablePositionedList inside AutomaticKeepAlive",
                        "build $index");
                    return widget.chatController.showLoadingPrevious.value &&
                            index == widget.chatList.length - 1
                        ? const Center(child: CircularProgressIndicator())
                        : const Offstage();
                  }),
                  (widget.chatList[index].messageType.toUpperCase() !=
                          Constants.mNotification)
                      ? SwipeTo(
                          onRightSwipe: (DragUpdateDetails dragUpdateDetails) {
                            if (!widget
                                    .chatList[index].isMessageRecalled.value &&
                                !widget.chatList[index].isMessageDeleted &&
                                widget.chatList[index].messageStatus.value
                                        .checkNull()
                                        .toString() !=
                                    "N") {
                              widget.chatController.handleReplyChatMessage(
                                  widget.chatList[index]);
                            }
                          },
                          animationDuration: const Duration(milliseconds: 300),
                          offsetDx: 0.2,
                          child: GestureDetector(
                            onLongPress: () {
                              debugPrint("LongPressed");
                              FocusManager.instance.primaryFocus?.unfocus();
                              if (!widget.chatController.isSelected.value) {
                                widget.chatController.isSelected(true);
                                widget.chatController
                                    .addChatSelection(widget.chatList[index]);
                              }
                            },
                            onTap: () {
                              debugPrint("On Tap");
                              FocusManager.instance.primaryFocus?.unfocus();
                              if (widget.chatController.isSelected.value) {
                                widget.chatController.isSelected.value
                                    ? widget.chatController.selectedChatList
                                            .contains(widget.chatList[index])
                                        ? widget.chatController
                                            .clearChatSelection(
                                                widget.chatList[index])
                                        : widget.chatController
                                            .addChatSelection(
                                                widget.chatList[index])
                                    : null;
                                widget.chatController.getMessageActions();
                              } else {
                                var replyChat = widget
                                    .chatList[index].replyParentChatMessage;
                                if (replyChat != null) {
                                  debugPrint("reply tap ");
                                  var chat = widget.chatList.indexWhere(
                                      (element) =>
                                          element.messageId ==
                                          replyChat.messageId);
                                  if (!chat.isNegative) {
                                    widget.chatController.navigateToMessage(
                                        widget.chatList[chat],
                                        index: chat);
                                  }
                                }
                              }
                            },
                            onDoubleTap: () {
                              widget.chatController.translateMessage(index);
                            },
                            child: Obx(() {
                              LogMessage.d("Container",
                                  "build ${widget.chatList[index].messageId}");
                              return Container(
                                key: ValueKey(widget.chatList[index].messageId),
                                color: widget.chatList[index].isSelected.value
                                    ? MirrorflyUikit.getTheme?.primaryColor
                                        .withAlpha(60)
                                    : Colors.transparent,
                                margin: const EdgeInsets.only(
                                    left: 14, right: 14, top: 5, bottom: 10),
                                child: Align(
                                  alignment:
                                      (widget.chatList[index].isMessageSentByMe
                                          ? Alignment.bottomRight
                                          : Alignment.bottomLeft),
                                  child: Row(
                                    crossAxisAlignment:
                                        CrossAxisAlignment.center,
                                    mainAxisSize: MainAxisSize.min,
                                    children: [
                                      Visibility(
                                        visible: widget.chatList[index]
                                                .isMessageSentByMe &&
                                            widget.chatController
                                                .forwardMessageVisibility(
                                                    widget.chatList[index]),
                                        child: IconButton(
                                            onPressed: () {
                                              widget.chatController
                                                  .forwardSingleMessage(widget
                                                      .chatList[index]
                                                      .messageId);
                                            },
                                            icon: SvgPicture.asset(
                                              package: package,
                                              forwardMedia,
                                            )),
                                      ),
                                      ChatContainer(
                                        chatMessage: widget.chatList[index],
                                        child: Column(
                                          crossAxisAlignment:
                                              CrossAxisAlignment.start,
                                          children: [
                                            if (widget.chatController.profile
                                                .isGroupProfile
                                                .checkNull()) ...[
                                              SenderHeader(
                                                  isGroupProfile: widget
                                                      .chatController
                                                      .profile
                                                      .isGroupProfile,
                                                  chatList: widget.chatList,
                                                  index: index),
                                            ],
                                            widget.chatList[index]
                                                    .isThisAReplyMessage
                                                ? widget.chatList[index]
                                                            .replyParentChatMessage ==
                                                        null
                                                    ? messageNotAvailableWidget(
                                                        widget.chatList[index])
                                                    : ReplyMessageHeader(
                                                        chatMessage: widget
                                                            .chatList[index])
                                                : const SizedBox.shrink(),
                                            MessageContent(
                                                chatList: widget.chatList,
                                                index: index,
                                                onPlayAudio: () {
                                                  if (widget
                                                          .chatController
                                                          .isAudioRecording
                                                          .value ==
                                                      Constants
                                                          .audioRecording) {
                                                    widget.chatController
                                                        .stopRecording();
                                                  }
                                                  widget.chatController
                                                      .playAudio(widget
                                                          .chatList[index]);
                                                },
                                                onSeekbarChange:
                                                    (double value) {
                                                  widget.chatController
                                                      .onSeekbarChange(
                                                          value,
                                                          widget
                                                              .chatList[index]);
                                                },
                                                isSelected: widget
                                                    .chatController
                                                    .isSelected
                                                    .value)
                                          ],
                                        ),
                                      ),
                                      if (!widget.chatList[index]
                                              .isMessageSentByMe &&
                                          widget.chatController
                                              .forwardMessageVisibility(
                                                  widget.chatList[index])) ...[
                                        IconButton(
                                            onPressed: () {
                                              widget.chatController
                                                  .forwardSingleMessage(widget
                                                      .chatList[index]
                                                      .messageId);
                                            },
                                            icon: SvgPicture.asset(
                                              package: package,
                                              forwardMedia,
                                            ))
                                      ],
                                    ],
                                  ),
                                ),
                              );
                            }),
                          ),
                        )
                      : NotificationMessageView(
                          chatMessage:
                              widget.chatList[index].messageTextContent),
                  Obx(() {
                    return widget.chatController.showLoadingNext.value &&
                            index == 0
                        ? const Center(
                            child: CircularProgressIndicator(),
                          )
                        : const Offstage();
                  }),
                ],
              );
            },
          );
        }),
      ),
    );
  }
  //
  // @override
  // bool get wantKeepAlive => true;
}
